# Integración de la función de distribución
# gausiana
# 18.01.2021

# Vamos a usar el método trapezoidal
# https://en.wikipedia.org/wiki/Trapezoidal_rule

# Se entrada se integrará hasta un valor de sigma
#    dado a la entrada
# Salida: el valor del área bajo la curva desde -s hasta s
#    donde s es la sigma

# Podemos aprovechar que la gausiana tiene simetría par
# y entonces integramos solo la mitad de la función
# Integramos desde 0 hasta s
# area = 2 \int_0^s
import sys
import math

# La función gausiana normalizada (mu=0, s=1)
def gaus( x ) :
	return math.exp( -x*x/2.0 )

n = len( sys.argv )
if n != 2 :
	print( "Args: valor_sigma" )
	sys.exit(1)

s = float( sys.argv[1] )

# Fijamos n muestras por cada sigma
n = int( s*20 + 1 )

suma = ( 1.0 + gaus( s ) )/2.0

deltax = s/n

i = 1
while i < n :
	x = i*deltax
	suma += gaus(x)
	i += 1

# El factor de escala
k = 1.0/math.sqrt(2.0*math.pi)

print( deltax*k*2.0*suma )
